==> uwikicms-1.0.2.tar.gz: uwikicms-1.0.2/php/_uwikicms/template/php/end.php <==
  <div id="actions" class="box admin">
  <ul>
  <? if ($this->need_action_root()) { ?>     
    <li><a href="<? echo $this->make_url(""); ?>"><? echo $this->translate("action_root"); ?></a></li>
<? } ?>	
    <li>
  <? if ($this->get_user_id()) { ?>
  <a href="<? echo $this->get_logout_url(); ?>"><?
       echo sprintf($this->translate("action_logout"), $this->get_user_label()); 
       ?></a>
<?
   } else {
     ?><a href="<? echo $this->get_loginform_url(); ?>"><?
       echo $this->translate("action_login");
       ?></a>
<? } ?>
</li>
<? if ($this->need_action_view()) { ?>
     <li><a href="<? echo $this->get_view_url(); ?>"><? echo $this->translate("action_view"); ?></a></li>
<? } ?>
<? if ($this->need_action_tree()) { ?>
     <li><a href="<? echo $this->get_tree_url(); ?>"><? echo $this->translate("action_tree"); ?></a></li>
<? } ?>
<? if ($this->need_action_allinone()) { ?>
     <li><a href="<? echo $this->get_allinoneform_url(); ?>"><? echo $this->translate("action_allinone"); ?></a></li>
<? } ?>
<? if ($this->need_action_update()) { ?>
     <li><a href="<? echo $this->get_updateform_url(); ?>"><? echo $this->translate("action_update"); ?></a></li>
<? } ?>
<? if ($this->need_action_imagenew()) { ?>
     <li><a href="<? echo $this->get_imagenew_url(); ?>"><? echo $this->translate("action_imagenew"); ?></a></li>
<? } ?>
<? if ($this->need_action_delete()) { ?>
     <li><a href="<? echo $this->get_deleteform_url(); ?>"><? echo $this->translate("action_delete"); ?></a></li>
<? } ?>
<? if ($this->need_action_translate()) { ?>
       <li><?echo $this->translate("translate");?>
       <? $first=true; ?>
     <? foreach ($this->get_untranslated() as $lang) { ?>
       <? if (!$first) { echo " | "; } $first=false; ?>
<a href="<? echo $this->get_translate_url($lang); ?>"><? echo $lang; ?></a>
<? } ?>
       </li>
<? } ?>
<? if ($this->need_action_clearcache()) { ?>
     <li><a href="<? echo $this->get_clearcacheform_url(); ?>"><? echo $this->translate("action_clearcache"); ?></a></li>
<? } ?>
  </ul>
<? if ($this->need_action_new()) { ?>
  <form method="post" action="<? echo $this->get_new_url(); ?>">
  <input type="hidden" name="path" value="<? echo $this->get_path(); ?>" />
  <input type="text" name="page" size="8" maxlength="32" value="" class="edit" />
  <input type="submit" name="submit" value="<? echo $this->translate("action_new"); ?>" class="button" />
  </form>
<? } ?>
  </div>

  <div id="infos" class="box system">
    <div id="credits">
    <? echo $this->translate1("page_generated_by_uwikicms", $this->today()); ?>
    </div>
    <? if ($this->need_rights()) { ?>
    <div id="rights">
    <? echo $this->get_rights(); ?>
    </div>
    <? } ?>
    <? if ($this->need_last_update()) { ?>
    <div id="lastupdate">
    <? echo $this->get_last_update(); ?>
    </div>
    <? } ?>
    <? if ($this->need_absolute_url()) { ?>
    <div id="absoluteurl">
      <? echo $this->translate("source"); ?>
      <a href="<? echo $this->get_absolute_url(); ?>"><? echo $this->get_absolute_url_clean(); ?></a>
    </div>
    <? } ?>
  </div>
  </body>
</html>

==> uwikicms-1.0.3.tar.gz: uwikicms-1.0.3/php/_uwikicms/template/php/end.php <==
  </div>

  <div id="block4">

  <div id="actions" class="box admin">
  <ul>
  <? if ($this->need_action_root()) { ?>     
    <li><a href="<? echo $this->make_url(""); ?>"><? echo $this->translate("action_root"); ?></a></li>
<? } ?>	
    <li>
  <? if ($this->get_user_id()) { ?>
  <a href="<? echo $this->get_logout_url(); ?>"><?
       echo sprintf($this->translate("action_logout"), $this->get_user_label()); 
       ?></a>
<?
   } else {
     ?><a href="<? echo $this->get_loginform_url(); ?>"><?
       echo $this->translate("action_login");
       ?></a>
<? } ?>
</li>
<? if ($this->need_action_view()) { ?>
     <li><a href="<? echo $this->get_view_url(); ?>"><? echo $this->translate("action_view"); ?></a></li>
<? } ?>
<? if ($this->need_action_tree()) { ?>
     <li><a href="<? echo $this->get_tree_url(); ?>"><? echo $this->translate("action_tree"); ?></a></li>
<? } ?>
<? if ($this->need_action_gallery()) { ?>
     <li><a href="<? echo $this->get_gallery_url(); ?>"><? echo $this->translate("action_gallery"); ?></a></li>
<? } ?>
<? if ($this->need_action_allinone()) { ?>
     <li><a href="<? echo $this->get_allinoneform_url(); ?>"><? echo $this->translate("action_allinone"); ?></a></li>
<? } ?>
<? if ($this->need_action_update()) { ?>
     <li><a href="<? echo $this->get_updateform_url(); ?>"><? echo $this->translate("action_update"); ?></a></li>
<? } ?>
<? if ($this->need_action_imagenew()) { ?>
     <li><a href="<? echo $this->get_imagenew_url(); ?>"><? echo $this->translate("action_imagenew"); ?></a></li>
<? } ?>
<? if ($this->need_action_delete()) { ?>
     <li><a href="<? echo $this->get_deleteform_url(); ?>"><? echo $this->translate("action_delete"); ?></a></li>
<? } ?>
<? if ($this->need_action_translate()) { ?>
       <li><?echo $this->translate("translate");?>
       <? $first=true; ?>
     <? foreach ($this->get_untranslated() as $lang) { ?>
       <? if (!$first) { echo " | "; } $first=false; ?>
<a href="<? echo $this->get_translate_url($lang); ?>"><? echo $lang; ?></a>
<? } ?>
       </li>
<? } ?>
<? if ($this->need_action_clearcache()) { ?>
     <li><a href="<? echo $this->get_clearcacheform_url(); ?>"><? echo $this->translate("action_clearcache"); ?></a></li>
<? } ?>
  </ul>
<? if ($this->need_action_new()) { ?>
  <form method="post" action="<? echo $this->get_new_url(); ?>">
  <input type="hidden" name="path" value="<? echo $this->get_path(); ?>" />
  <input type="text" name="page" size="8" maxlength="32" value="" class="edit" />
  <input type="submit" name="submit" value="<? echo $this->translate("action_new"); ?>" class="button" />
  </form>
<? } ?>
  </div>

  </div>

  <div id="block5">

  <div id="infos" class="box system">
    <div id="credits">
    <? echo $this->translate1("page_generated_by_uwikicms", $this->today()); ?>
    </div>
    <? if ($this->need_rights()) { ?>
    <div id="rights">
    <? echo $this->get_rights(); ?>
    </div>
    <? } ?>
    <? if ($this->need_last_update()) { ?>
    <div id="lastupdate">
    <? echo $this->get_last_update(); ?>
    </div>
    <? } ?>
    <? if ($this->need_absolute_url()) { ?>
    <div id="absoluteurl">
      <? echo $this->translate("source"); ?>
      <a href="<? echo $this->get_absolute_url(); ?>"><? echo $this->get_absolute_url_clean(); ?></a>
    </div>
    <? } ?>
  </div>

  </div>

  </body>
</html>
